#
# spec file for package lua-luarocks
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define flavor lua53
%define mod_name luarocks
%define lua_value  %(echo "%{flavor}" |sed -e 's:lua::')
Version:        2.4.2
Release:        bp156.3.1
Summary:        A deployment and management system for Lua modules
License:        MIT
Group:          Development/Languages/Other
Url:            https://luarocks.org
Source:         https://github.com/luarocks/luarocks/archive/v%{version}.tar.gz#/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{flavor}-devel
BuildRequires:  curl
BuildRequires:  openssl
BuildRequires:  unzip
Requires:       %{flavor}
Requires:       curl
Requires:       openssl
Requires:       unzip
BuildArch:      noarch
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
LuaRocks allows you to install Lua modules as self-contained packages
called "rocks", which also contain version dependency
information. This information is used both during installation, so
that when one rock is requested all rocks it depends on are installed
as well, and at run time, so that when a module is required, the
correct version is loaded. LuaRocks supports both local and remote
repositories, and multiple local rocks trees.

%prep
%setup -q -n %{mod_name}-%{version}

%build
# Not an autotools based system
./configure \
  --prefix=%{_prefix} \
  --lua-version=%{lua_version} \
  --with-downloader=curl \
  --with-md5-checker=openssl \
  --versioned-rocks-dir
make %{?_smp_mflags} build

%install
%make_install
# Add C module lib directory to fix "built" rocks not working
# See https://github.com/keplerproject/luarocks/issues/416
%if %{_lib}==lib64
echo -e -n "\nlib_modules_path=\"/%{_lib}/lua/\"..lua_version" >> %{buildroot}%{_sysconfdir}/luarocks/config-%{lua_version}.lua
%endif

# update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/luarocks
ln -sf %{_sysconfdir}/alternatives/luarocks %{buildroot}%{_bindir}/luarocks
touch %{buildroot}%{_sysconfdir}/alternatives/luarocks-admin
ln -sf %{_sysconfdir}/alternatives/luarocks %{buildroot}%{_bindir}/luarocks-admin

%post
%{_sbindir}/update-alternatives --install %{_bindir}/luarocks luarocks %{_bindir}/luarocks-%{lua_version} %{lua_value} \
  --slave %{_bindir}/luarocks-admin luarocks-admin %{_bindir}/luarocks-%{lua_version}

%postun
if [ "$1" = 0 ] ; then
	%{_sbindir}/update-alternatives --remove luarocks %{_bindir}/luarocks-%{lua_version}
fi

%files
%doc COPYING README.md
%dir %{_sysconfdir}/luarocks
%config(noreplace) %{_sysconfdir}/luarocks/config-%{lua_version}.lua
%ghost %{_sysconfdir}/alternatives/luarocks
%ghost %{_sysconfdir}/alternatives/luarocks-admin
%{_bindir}/luarocks
%{_bindir}/luarocks-admin
%{_bindir}/luarocks-%{lua_version}
%{_bindir}/luarocks-admin-%{lua_version}
%{lua_noarchdir}/luarocks

%changelog
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Fri Jul 14 2017 tchvatal@suse.com
- Switch to multibuild to produce luarocks for all lua variants
* Fri Jul 14 2017 tchvatal@suse.com
- Version update to 2.4.2:
  * New test suite based on Busted; runs on Linux, OSX and Windows
  * git+ssh:// fetch protocol
  * Improved behavior preserving permissions
  * Improved listing of dependencies on installation
  * Improved behavior of argument handling in `pack`
  * MSYS and Haiku platform detection
  * Feature-based detection of internal bit32 and utf8 modules
  * Internal reorganization of luarocks.fs code
  * `remove` option --force=fast renamed to --force-fast
  * Plus assorted bugfixes and cleanups
  * Avoid coroutine use in luarocks.loader
  * Fix upgrade issues for very old versions
  * Fixed conflict resolution on deploy/delete
  * Improved dependency check messages
  * Performance improvements when removing packages
  * Support user-defined `platforms` array in config file
  * Improvements in Lua interpreter version detection in Unix configure script
  * Relaxed Lua version detection to improve support for alternative implementations (e.g. Ravi)
  * Plus assorted bugfixes and improvements
* Mon Jul  4 2016 opensuse@mirell.de
- update to version 2.3.0
  * Windows: major redesign of the install tree structure
  * Windows: Auto setup of MSVC environments
  * Improve error messages when tools are not installed
  * CMake: generate 64-bit builds when appropriate
  * Improve check of location of config files
  * MacOSX: set MACOSX_DEPLOYMENT_TARGET using env
  * Remove --extensions flag; use rockspec_format instead
  * New `luarocks config` command to query configuration
  * Improved UI for messages when external deps are missing
  * Unix: Robustness improvement in configure script
  * Plus tweaks and bugfixes. See the changelog for details.
- Add correct library directory to configuration file to fix
  rocks that use C modules on x86_64 architecture
* Sat Jul 18 2015 i@marguerite.su
- update version 2.2.2
  * `luarocks build --only-deps` and `luarocks install --only-deps`
    for installing dependencies only
  * Mercurial support
  * Improved command-line argument parser, now validates arguments
    (it previously ignored unrecognized arguments) and accepts both
    `--flag=option` and `--flag option` in flags that take arguments.
  * For consistency with `luarocks show`, `luarocks doc --homepage`
    is now `luarocks doc --home`
  * Improvements to CMake build backend
  * Improved Makefiles for handling simultaneous bootstrapped
    installations
  * Various bugfixes
- changes in 2.2.1
  * Improved compatibility with Lua 5.3
  * `luarocks list --outdated` for listing modules with available
    upgrades
  * Assorted bugfixes
* Mon Oct 20 2014 i@marguerite.su
- update version 2.2.0
  * MoonRocks is the new default repository: http://rocks.moonscript.org
    Rocks don't need to be sent to the LuaRocks mailing list anymore,
    you can upload them directly at the website or using
  `luarocks upload` command for uploading rocks to MoonRocks via
    the command-line
  * Preliminary support for Lua 5.3
  * No longer uses the module() function, for Lua 5.2 installations
    built without Lua 5.1 compatibility
  * --branch flag for `luarocks build` and `luarocks make`
  * various improvements in `luarocks doc` command
  * "git+http" transport for source.url
* Mon Jan 21 2013 kianseong@gmail.com
- Updated version and made some changes
* Fri Sep 21 2012 toganm@opensuse.org
- Initial packaging
